from fractions import Fraction

mols = []
atoms = []

# read in all molecules and build the list of unique atoms
while True:
    l = input()

    if l[0] == "0": break

    mol = l.split()

    for m in mol[2::2]:
        if m not in atoms:
            atoms.append(m)

    mols.append(mol)

# build the system of equations:
#  variables are molecues, rows are equations asserting the total net use
#  of each atom is 0
a = [[Fraction(0,1)]*len(mols) for _ in atoms]

for i in range(len(mols)):
    for j in range(2, len(mols[i]), 2):
        a[atoms.index(mols[i][j])][i] += Fraction(int(mols[i][j+1]), int(mols[i][0]))

# now do row-reduction to get into reduced row-echelon form
# the problem statement guarantees a unique "reduced" solution meaning
# there should be one free variable parameterizing the solutions ot A*x == 0
# where A is the "a" matrix we just built and x is the vector of variables
# indicating how many times each molecule is used
r = 0
for c in range(len(a[0])):
    # find a nonzero value to pivot on
    piv = r
    while piv < len(a) and a[piv][c] == 0:
        piv += 1
    if piv == len(a): continue

    # swap the pivot row to the current row
    a[r], a[piv] = a[piv], a[r]

    # normalize this row to have a leading 1
    a[r] = [x/a[r][c] for x in a[r]]

    # subtract an appropriate multiple of this row to all others to clear
    # out this column completely (i.e. afterward column c should have 0s
    # everywhere except a 1 at the pivot row)
    for rr in range(len(a)):
        if r != rr and a[rr][c] != 0:
            a[rr] = [a[rr][j] - a[r][j]*a[rr][c] for j in range(len(a[0]))]

    # next!
    r += 1

# At this point we know the solutions to A*x == 0 are one-dimensional
# so are of the form t * (x_1, x_2, ..., x_m) for some particular x.
# In particular, we can get x from the last column of the system, restricted
# to the nonzero rows.

# Our goal is set t so thes are all positive integers with gcd() == 1,
# so we should compute the LCM of all denominators of the x_i.
def gcd(x, y):
    return x if y == 0 else gcd(y, x%y)

def lcm(x, y):
    return x//gcd(x,y)*y

scale = 1
for row in a:
    scale = lcm(scale, row[-1].denominator)

# Now use t == "scale" and don't forget to append the last entry of the output vector!

sol = [-row[-1].numerator*scale//row[-1].denominator for row in a[:len(mols)-1]] + [scale]

print(*sol)
